@@ -164,9 +164,20 @@ bool FlatpakReference::isDefaults() const
 
 static GPtrArray *getSystemInstalledFlatpakAppRefs()
 {
-    g_autoptr(FlatpakInstallation) installation = flatpak_installation_new_system(nullptr, nullptr);
-    GPtrArray *refs = flatpak_installation_list_installed_refs_by_kind(installation, FLATPAK_REF_KIND_APP, nullptr, nullptr);
-    return refs;
+    auto ret = g_ptr_array_new();
+
+    g_autoptr(GPtrArray) installations = flatpak_get_system_installations(nullptr, nullptr);
+    g_ptr_array_foreach(
+        installations,
+        [](gpointer data, gpointer user_data) {
+            auto installation = FLATPAK_INSTALLATION(data);
+            auto ret = static_cast<GPtrArray *>(user_data);
+            g_autoptr(GPtrArray) refs = flatpak_installation_list_installed_refs_by_kind(installation, FLATPAK_REF_KIND_APP, nullptr, nullptr);
+            g_ptr_array_extend_and_steal(ret, refs);
+        },
+        ret);
+
+    return ret;
 }
 
 static GPtrArray *getUserInstalledFlatpakAppRefs()
@@ -185,8 +196,7 @@ FlatpakReferencesModel::FlatpakReferencesModel(QObject *parent)
     const auto systemOverridesDirectory = FlatpakHelper::systemOverridesDirectory();
     const auto userOverridesDirectory = FlatpakHelper::userOverridesDirectory();
 
-    const std::array installedRefs = std::array{systemInstalledRefs, userInstalledRefs};
-    for (const auto &refs : installedRefs) {
+    for (const auto &refs : {systemInstalledRefs, userInstalledRefs}) {
         for (uint i = 0; i < refs->len; ++i) {
             auto *ref = FLATPAK_REF(g_ptr_array_index(refs, i));
             auto *iRef = FLATPAK_INSTALLED_REF(g_ptr_array_index(refs, i));
@@ -224,7 +234,7 @@ FlatpakReferencesModel::FlatpakReferencesModel(QObject *parent)
         }
     }
 
-    std::sort(m_references.begin(), m_references.end(), [](const FlatpakReference *r1, const FlatpakReference *r2) {
+    std::ranges::sort(m_references, [](const FlatpakReference *r1, const FlatpakReference *r2) {
         return r1->displayName() < r2->displayName();
     });
 }
@@ -240,10 +250,10 @@ int FlatpakReferencesModel::rowCount(const QModelIndex &parent) const
 QVariant FlatpakReferencesModel::data(const QModelIndex &index, int role) const
 {
     if (!index.isValid()) {
-        return QVariant();
+        return {};
     }
 
-    switch (role) {
+    switch (Roles(role)) {
     case Roles::Name:
         return m_references.at(index.row())->displayName();
     case Roles::Version:
@@ -253,7 +263,7 @@ QVariant FlatpakReferencesModel::data(const QModelIndex &index, int role) const
     case Roles::Ref:
         return QVariant::fromValue<FlatpakReference *>(m_references.at(index.row()));
     }
-    return QVariant();
+    return {};
 }
 
 QHash<int, QByteArray> FlatpakReferencesModel::roleNames() const
